==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ar/pub.php <==
<?php
regGS("Publication List", "");
regGS("Go To Issues", "");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", " الاسم (اضغط لترى الإصدارات)");
regGS("Delete publication $1", "الغاء المنشور $1");
regGS("No publications.", "لا يوجد منشور");
regGS("Default Site Alias", "أسم الموقع الإفتراضي");
regGS("URL Type", "نوع الرابط");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "البلد<br> (اضغط للتعديل(");
regGS("Delete alias $1", "الغاء بيانات الدخول $1");
regGS("Configure publication", "إعدادات المنشور");
regGS("You do not have the right to edit publication information.", "لا يحق لك تحرير المعلومات الخاصة بالمنشور");
regGS("General attributes", "الخصائص العامة");
regGS("Subscriptions defaults", "إفتراضيات الإشتراكات");
regGS("Countries defaults", "إفتراضيات الدول");
regGS("Changing publication information", "تبديل المعلومات الخاصة بالمنشور");
regGS("You do not have the right to change publication information.", "لا يحق لك تغيير المعلومات الخاصة بالمنشور");
regGS("The publication information could not be updated.", "لا يمكن تحديث المعلومات الخاصة بالمنشور");
regGS("Please check if another publication with the same name or the same site name does not already exist.", "الرجاء التأكد من عدم وجود منشور يحمل الاسم نفسه أو اسم الموقع نفسه");
regGS("You do not have the right to delete publications.", "لا يحق لك إلغاء المنشورات");
regGS("Are you sure you want to delete the publication $1?", "هل أنت متأكد من أنك تريد إلغاء المنشور $1");
regGS("Deleting publication", "إلغاء المنشور");
regGS("There are $1 subscription(s) left.", "اشتراك $1 (اشتراكات) متبقية");
regGS("The publication $1 could not be deleted.", "لا  يمكن إلغاء المنشور$1");
regGS("Adding new publication", "إضافة منشور جديد");
regGS("The publication could not be added.", "لا يمكن إضافة المنشور");
regGS("Select the publication", "اختر المنشور");
regGS("Add new country default subscription time", "أضف مدّة الاشتراك الأصلية خاصة بالبلد الجديد");
regGS("You do not have the right to manage publications.", "لا يحق لك إدارة المنشورات");
regGS("Please check if another entry with the same country code exists already.", "الرجاء التأكد من عدم وجود إدخال أخر بنفس رمز الدولة");
regGS("Adding new country default subscription time", "إضافة مدّة اشتراك الأصلية خاصة بالبلد الجديد");
regGS("You must select a country.", "اختر بلداً");
regGS("The default subscription time for country $1 could not be added.", "لا يمكن إضافة مدة الاشتراك الأصلية للبلد $1");
regGS("Change subscription default time", "قم بتغيير مدّة الاشتراك الأصلية");
regGS("Default subscription time for $1 changed", " تغيير مدّة الاشتراك الأصلية لـ $1");
regGS("Are you sure you want to delete the subscription default time for $1?", "هل أنت متأكد من أنك تريد إلغاء مدّة الاشتراك الأصلية لـ $1 ؟");
regGS("Subscription default time for $1 deleted", "تمّ الغاء مدّة الاشتراك الأصلية لـ $1");
regGS("Name<BR><SMALL>(click to select the publication)</SMALL>", "الاسم (اضغط هنا لاختيار المنشور");
regGS("Add new alias", "أضف اسم مستعار جديد");
regGS("Alias (click to edit)", "الاسم المستعار ( اضغط للتعديل)");
regGS("Edit aliases", "تعديل الاسم المستعار");
regGS("Publication Aliases", "اسم المنشور المستعار");
regGS("Adding new alias", "اضافة اسم مستعار جديد");
regGS("The site alias $1 has been added to publication $2.", "تم اضافة اسم الموقع المستعار 1 المنشور 2$");
regGS("The site alias $1 could not be added.", "لم يتم اضافة اسم الموقع المستعار 1$");
regGS("Another alias with the same name exists already.", "هنالك اسم مستعار آخر بنفس الاسم");
regGS("Edit alias", "تعديل الاسم المستعار");
regGS("Editing alias", "تعديل الاسم المستعار");
regGS("The site alias for publication $1 has been modified to $2.", "تم تعديل اسم الموقع المستعار للمنشور 1$ الى 2$");
regGS("The site alias $1 could not be modified.", "لم يتم تعديل اسم الموقع المستعار 1$");
regGS("Are you sure you want to delete the alias $1?", "هل انت متأكد من حذف الاسم المستعار 1");
regGS("Deleting alias", "حذف الاسم المستعار");
regGS("The alias $1 could not be deleted.", "لم يتم حذف الاسم المستعار 1$");
regGS("The alias $1 has been deleted from publication $2.", "تم حذف الاسم المستعار 1$ من  المنشور 2$");
regGS("$1 is the default publication alias, it can not be deleted.", "لا يمكن الغاء الاسم المستعار 1$ لانه الاسم الافتراضي");
regGS("You do not have the right to add publications.", "لا تملك صلاحية اضافة منشورات");
?>

==> campsite-2.6.7_5.tbz: campsite/www-common/html/priv/lang/ar/pub.php <==
<?php 
regGS("Use CAPTCHA to prevent spam?", "");
regGS("Public allowed to comment?", "");
regGS("Enable spam blocking?", "");
regGS("The subscription settings for '$1' could not be added.", "");
regGS("The publication name you specified conflicts with publication '$1'.", "");
regGS("The publication alias you specified conflicts with publication '$1'.", "");
regGS("Subscription defaults", "");
regGS("Subscription Settings by Country", "");
regGS("Set subscription settings for a country", "");
regGS("Set subscription settings by country", "");
regGS("Default time periods:", "");
regGS("Country subscription settings updated.", "");
regGS("Country subscription settings deleted.", "");
regGS("Change country subscription settings", "");
regGS("Are you sure you want to delete the subscription settings for $1?", "");
regGS("Publication updated", "");
regGS("Subscriber comments moderated?", "");
regGS("Public comments moderated?", "");
regGS("Comments enabled?", "");
regGS("Comments enabled", "");
regGS("Article comments default to enabled?", "");
regGS("trial subscription", "إشتراك تجريبي");
regGS("paid subscription", "إشتراك مدفوع");
regGS("time units", "وحدات الوقت");
regGS("one language", "لغة واحدة");
regGS("all languages", "جميع اللغات");
regGS("Trial subscriptions", "أشتراكات تجريبية");
regGS("Time unit cost per one section", "كلفة وحدة الوقت لقسم واحد");
regGS("Paid subscriptions", "إشتراكات مدفوعة");
regGS("Default time period", "مدة الوقت الإفتراضية");
regGS("Go To Issues", "إذهب للأعداد");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", " الاسم (اضغط لترى الإصدارات)");
regGS("Delete publication $1", "الغاء المنشور $1");
regGS("No publications.", "لا يوجد منشور");
regGS("Default Site Alias", "أسم الموقع الإفتراضي");
regGS("URL Type", "نوع الرابط");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "البلد<br> (اضغط للتعديل(");
regGS("Delete alias $1", "الغاء بيانات الدخول $1");
regGS("Configure publication", "إعدادات المنشور");
regGS("You do not have the right to edit publication information.", "لا يحق لك تحرير المعلومات الخاصة بالمنشور");
regGS("General attributes", "الخصائص العامة");
regGS("You do not have the right to change publication information.", "لا يحق لك تغيير المعلومات الخاصة بالمنشور");
regGS("The publication information could not be updated.", "لا يمكن تحديث المعلومات الخاصة بالمنشور");
regGS("You do not have the right to delete publications.", "لا يحق لك إلغاء المنشورات");
regGS("Are you sure you want to delete the publication $1?", "هل أنت متأكد من أنك تريد إلغاء المنشور $1");
regGS("Deleting publication", "إلغاء المنشور");
regGS("There are $1 subscription(s) left.", "اشتراك $1 (اشتراكات) متبقية");
regGS("The publication $1 could not be deleted.", "لا  يمكن إلغاء المنشور$1");
regGS("The publication could not be added.", "لا يمكن إضافة المنشور");
regGS("You do not have the right to manage publications.", "لا يحق لك إدارة المنشورات");
regGS("You must select a country.", "اختر بلداً");
regGS("Default subscription time for $1 changed", " تغيير مدّة الاشتراك الأصلية لـ $1");
regGS("Subscription default time for $1 deleted", "تمّ الغاء مدّة الاشتراك الأصلية لـ $1");
regGS("Add new alias", "أضف اسم مستعار جديد");
regGS("Alias (click to edit)", "الاسم المستعار ( اضغط للتعديل)");
regGS("Edit aliases", "تعديل الاسم المستعار");
regGS("Publication Aliases", "اسم المنشور المستعار");
regGS("Adding new alias", "اضافة اسم مستعار جديد");
regGS("The site alias $1 has been added to publication $2.", "تم اضافة اسم الموقع المستعار 1 المنشور 2$");
regGS("The site alias $1 could not be added.", "لم يتم اضافة اسم الموقع المستعار 1$");
regGS("Another alias with the same name exists already.", "هنالك اسم مستعار آخر بنفس الاسم");
regGS("Edit alias", "تعديل الاسم المستعار");
regGS("Editing alias", "تعديل الاسم المستعار");
regGS("The site alias for publication $1 has been modified to $2.", "تم تعديل اسم الموقع المستعار للمنشور 1$ الى 2$");
regGS("The site alias $1 could not be modified.", "لم يتم تعديل اسم الموقع المستعار 1$");
regGS("Are you sure you want to delete the alias $1?", "هل انت متأكد من حذف الاسم المستعار 1");
regGS("Deleting alias", "حذف الاسم المستعار");
regGS("The alias $1 could not be deleted.", "لم يتم حذف الاسم المستعار 1$");
regGS("The alias $1 has been deleted from publication $2.", "تم حذف الاسم المستعار 1$ من  المنشور 2$");
regGS("$1 is the default publication alias, it can not be deleted.", "لا يمكن الغاء الاسم المستعار 1$ لانه الاسم الافتراضي");
regGS("You do not have the right to add publications.", "لا تملك صلاحية اضافة منشورات");
regGS("There are $1 issue(s) left.", "هنالك $1 أعداد متبقية.");
regGS("Time Unit", "وحدة الوقت");
regGS("Currency", "العملة");
regGS("Edit languages", "تعديل اللغات");
?>
